@@ -31,6 +31,6 @@ def read_amazon_review_data():
 
   return read
 
-download_amazon_review_core5_data = lambda path, category: download(
+download_amazon_review_core5_data = lambda path, category: lambda: download(
   path, CATEGORY_FILE(category), root_url=AMAZON_REVIEWS_ROOT_URL
 )
\ No newline at end of file
